//DrawableButton Component
import 'package:flutter/material.dart';
import 'package:synth/src/color_page.dart';

class SynthDrawablebutton extends StatelessWidget {
  SynthDrawablebutton({
    Key? key,
    required this.text,
    required this.width,
    required this.height,
    required this.onPressed,
  }) : super(key: key);
  final String text;
  final double width;
  final double height;

  final GestureTapCallback onPressed;
  final isPressed = ValueNotifier<bool>(false);

  void change() {
    if (isPressed.value) {
      isPressed.value = false;
      Future.delayed(const Duration(milliseconds: 400), () {
        isPressed.value = true;
      });
    } else {
      isPressed.value = true;
      Future.delayed(const Duration(milliseconds: 400), () {
        isPressed.value = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    var radius = 0.7 * height;
    return SizedBox(
      width: width,
      height: height,
      child: GestureDetector(
        onTap: () => [onPressed, change()],
        onLongPress: () => change(),
        child: ValueListenableBuilder(
          valueListenable: isPressed,
          builder: (context, value, widget) => AnimatedContainer(
            //curve: Curves.easeInOutQuint,
            duration: const Duration(milliseconds: 200),
            decoration: BoxDecoration(
              gradient: isPressed.value
                  ? LinearGradient(
                      colors: [
                        primarySynthBlack400,
                        primarySynthBlack,
                      ],
                      begin: Alignment.centerLeft,
                      end: Alignment.centerRight,
                    )
                  : LinearGradient(colors: [
                      primarySynthBlack.withOpacity(0.3),
                      primarySynthBlack200,
                    ], begin: Alignment.topLeft, end: Alignment.bottomRight),
              borderRadius: BorderRadius.circular(100),
              border: isPressed.value
                  ? Border.all(
                      color: primarySynthBlack.withOpacity(0.05), width: 4)
                  : Border.all(
                      color: primarySynthBlack.withOpacity(0.22), width: 4),
              boxShadow: [
                BoxShadow(
                  color: primarySynthWhite.withOpacity(0.2),
                  blurRadius: 15.0, // soften the shadow
                  spreadRadius: 10, //extend the shadow
                  offset: const Offset(
                    -3.0, // Move to right 10  horizontally
                    -3.0, // Move to bottom 10 Vertically
                  ),
                ),
                BoxShadow(
                  color: primaryBlack.withOpacity(0.4),
                  blurRadius: 15.0, // soften the shadow
                  spreadRadius: 10, //extend the shadow
                  offset: const Offset(
                    6.0, // Move to right 10  horizontally
                    10.0, // Move to bottom 10 Vertically
                  ),
                ),
              ],
            ),
            child: Center(
              child: Padding(
                padding: const EdgeInsets.symmetric(horizontal: 10),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    SizedBox(
                      width: radius,
                      height: radius,
                      child: Container(
                        decoration: BoxDecoration(
                          border: Border.all(
                              width: 3, color: primaryBlack.withOpacity(0.04)),
                          gradient: isPressed.value
                              ? LinearGradient(
                                  colors: [
                                      primaryBlack.withAlpha(40),
                                      primarySynthBlack,
                                    ],
                                  begin: Alignment.topLeft,
                                  end: Alignment.bottomRight)
                              : LinearGradient(
                                  colors: [
                                      primarySynthBlack400.withOpacity(0.8),
                                      //primarySynthBlack400.withOpacity(0.7),
                                      primarySynthBlack
                                    ],
                                  begin: Alignment.topLeft,
                                  end: Alignment.bottomRight),
                          borderRadius: BorderRadius.circular(radius),
                        ),
                        child: Icon(
                          Icons.add,
                          size: 0.50 * radius,
                          color: primarySynthCopper40,
                        ),
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.only(left: 30),
                      child: Text(
                        text,
                        style: TextStyle(
                          fontSize: 20,
                          fontFamily: 'Gilroy',
                          fontWeight: FontWeight.w400,
                          color: isPressed.value
                              ? primarySynthCopper40
                              : primarySynthCopper400,
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
