//FlatButton Component
import 'package:flutter/material.dart';

import 'color_page.dart';

class SynthFlatbutton extends StatelessWidget {
  SynthFlatbutton(
      {Key? key,
      required this.text,
      required this.width,
      required this.height,
      required this.onPressed,
      required this.icon})
      : super(key: key);
  final String text;
  final double width;
  final double height;
  final Icon icon;
  final GestureTapCallback onPressed;
  final isPressed = ValueNotifier<bool>(false);
  void change() {
    if (isPressed.value) {
      isPressed.value = false;
      Future.delayed(const Duration(milliseconds: 400), () {
        isPressed.value = true;
      });
    } else {
      isPressed.value = true;
      Future.delayed(const Duration(milliseconds: 400), () {
        isPressed.value = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: width,
      height: height,
      child: GestureDetector(
        onTap: () => [onPressed, change()],
        onLongPress: () => change(),
        child: ValueListenableBuilder(
          valueListenable: isPressed,
          builder: (context, value, widget) => AnimatedContainer(
            duration: const Duration(milliseconds: 200),
            decoration: BoxDecoration(
              gradient: isPressed.value
                  ? primarySynthBlueDarkGradient
                  : primarySynthBlueGradient,
              borderRadius: BorderRadius.circular(100),
              border: isPressed.value
                  ? Border.all(color: primarySynthBlack, width: 4)
                  : Border.all(color: primarySynthBlack, width: 4),
              boxShadow: [
                BoxShadow(
                  color: primarySynthWhite.withOpacity(0.2),
                  blurRadius: 15.0, // soften the shadow
                  spreadRadius: 6, //extend the shadow
                  offset: const Offset(
                    -8.0, // Move to right 10  horizontally
                    -6.0, // Move to bottom 10 Vertically
                  ),
                ),
                BoxShadow(
                  color: primaryBlack.withOpacity(0.4),
                  blurRadius: 20.0, // soften the shadow
                  spreadRadius: 10, //extend the shadow
                  offset: const Offset(
                    5.0, // Move to right 10  horizontally
                    12.0, // Move to bottom 10 Vertically
                  ),
                ),
              ],
            ),
            child: Center(
              child: Padding(
                padding: const EdgeInsets.symmetric(horizontal: 10),
                child: Text(
                  text,
                  style: TextStyle(
                    fontSize: 20,
                    fontFamily: 'Gilroy',
                    fontWeight: FontWeight.w400,
                    color: isPressed.value
                        ? primarySynthWhite
                        : primarySynthWhite100,
                  ),
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
