//Softbutton Component
import 'package:flutter/material.dart';

import 'color_page.dart';

class SynthSoftbutton extends StatelessWidget {
  SynthSoftbutton({
    Key? key,
    required this.text,
    required this.width,
    required this.height,
    required this.onPressed,
  }) : super(key: key);
  final String text;
  final double width;
  final double height;
  final GestureTapCallback onPressed;

  final isPressed = ValueNotifier<bool>(false);

  void change() {
    if (isPressed.value) {
      isPressed.value = false;
      Future.delayed(const Duration(milliseconds: 400), () {
        isPressed.value = true;
      });
    } else {
      isPressed.value = true;
      Future.delayed(const Duration(milliseconds: 400), () {
        isPressed.value = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: width,
      height: height,
      child: GestureDetector(
        onTap: () => [onPressed, change()],
        onLongPress: () => change(),
        child: ValueListenableBuilder(
          valueListenable: isPressed,
          builder: (context, value, widget) => AnimatedContainer(
            duration: const Duration(milliseconds: 200),
            decoration: BoxDecoration(
              gradient: isPressed.value == true
                  ? LinearGradient(colors: [
                      primarySynthBlack400,
                      primarySynthBlack,
                    ], begin: Alignment.topLeft, end: Alignment.bottomRight)
                  : LinearGradient(
                      colors: [
                        primarySynthBlack.withOpacity(0.4),
                        primarySynthBlack200
                      ],
                      begin: Alignment.bottomLeft,
                      end: Alignment.bottomRight,
                      stops: const [0.95, 1],
                    ),
              borderRadius: BorderRadius.circular(100),
              border: Border.all(
                color: primarySynthBlack.withOpacity(0.22),
                width: 3,
              ),
              boxShadow: [
                BoxShadow(
                  color: primarySynthWhite.withOpacity(0.2),
                  blurRadius: 15.0, // soften the shadow
                  spreadRadius: 10, //extend the shadow
                  offset: const Offset(
                    -3.0, // Move to right 10  horizontally
                    -3.0, // Move to bottom 10 Vertically
                  ),
                ),
                BoxShadow(
                  color: primaryBlack.withOpacity(0.43),
                  blurRadius: 20.0, // soften the shadow
                  spreadRadius: 5, //extend the shadow
                  offset: const Offset(
                    5.0, // Move to right 10  horizontally
                    12.0, // Move to bottom 10 Vertically
                  ),
                ),
              ],
            ),
            child: Center(
              child: Text(
                text,
                style: TextStyle(
                  fontSize: 15,
                  fontFamily: 'Gilroy',
                  fontWeight: FontWeight.w400,
                  color: isPressed.value
                      ? primarySynthCopper40
                      : primarySynthCopper400,
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
